@@ -5,12 +5,12 @@ use warnings;
 package Dist::Zilla::Plugin::InstallGuide;
 
 # ABSTRACT: Build an INSTALL file
-our $VERSION = '1.200009'; # VERSION
+our $VERSION = '1.200010'; # VERSION
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::TextTemplate';
 with 'Dist::Zilla::Role::FileMunger';
-use List::Util 'first';
+use List::Util 1.33 qw(first any);
 
 
 has template => (is => 'ro', isa => 'Str', default => <<'END_TEXT');
@@ -38,23 +38,39 @@ Alternatively, if your CPAN shell is set up, you should just be able to do:
 ## Manual installation
 
 {{ $manual_installation }}
-
 The prerequisites of this distribution will also have to be installed manually. The
 prerequisites are listed in one of the files: `MYMETA.yml` or `MYMETA.json` generated
 by running the manual build process described above.
 
+## Configure Prerequisites
+
+This distribution requires other modules to be installed before this
+distribution's installer can be run.  They can be found under the
+{{ join(" or the\n",
+    $has_meta_yml ? '"configure_requires" key of META.yml' : '',
+    $has_meta_json ? '"{prereqs}{configure}{requires}" key of META.json' : '',
+)}}.
+
 ## Documentation
 
 {{ $dist->name }} documentation is available as POD.
 You can run `perldoc` from a shell to read the documentation:
 
     % perldoc {{ $package }}
+
+For more information on installing Perl modules via CPAN, please see:
+https://www.cpan.org/modules/INSTALL.html
 END_TEXT
 
-has makemaker_manual_installation => (is => 'ro', isa => 'Str', default => <<'END_TEXT');
+our $common_instructions = <<'END_TEXT';
 As a last resort, you can manually install it. Download the tarball, untar it,
-then build it:
+install configure prerequisites (see below), then build it:
 
+END_TEXT
+
+has makemaker_manual_installation => (
+    is => 'ro', isa => 'Str',
+    default => $common_instructions . <<'END_TEXT',
     % perl Makefile.PL
     % make && make test
 
@@ -68,11 +84,11 @@ If your perl is system-managed, you can create a local::lib in your home
 directory to install modules to. For details, see the local::lib documentation:
 https://metacpan.org/pod/local::lib
 END_TEXT
+);
 
-has module_build_manual_installation => (is => 'ro', isa => 'Str', default => <<'END_TEXT');
-As a last resort, you can manually install it. Download the tarball, untar it,
-then build it:
-
+has module_build_manual_installation => (
+    is => 'ro', isa => 'Str',
+    default => $common_instructions . <<'END_TEXT',
     % perl Build.PL
     % ./Build && ./Build test
 
@@ -91,23 +107,17 @@ If your perl is system-managed, you can create a local::lib in your home
 directory to install modules to. For details, see the local::lib documentation:
 https://metacpan.org/pod/local::lib
 END_TEXT
-
-has cpan_reference => (is => 'ro', isa => 'Str', default => <<END_TEXT);
-For more information on installing Perl modules via CPAN, please see:
-https://www.cpan.org/modules/INSTALL.html
-END_TEXT
+);
 
 
 sub gather_files {
     my $self = shift;
 
-    my $content = $self->template;
-    $content .= $self->cpan_reference;
-
     require Dist::Zilla::File::InMemory;
     $self->add_file(Dist::Zilla::File::InMemory->new({
         name => 'INSTALL',
-        content => $content,
+        content => $self->template,
+
     }));
 
     return;
@@ -147,6 +157,8 @@ sub munge_files {
         {   dist                => \$zilla,
             package             => $main_package,
             manual_installation => $manual_installation,
+            has_meta_yml        => (any { $_->name eq 'META.yml' } @{ $zilla->files }),
+            has_meta_json       => (any { $_->name eq 'META.json' } @{ $zilla->files }),
         }
     );
 
@@ -170,7 +182,7 @@ Dist::Zilla::Plugin::InstallGuide - Build an INSTALL file
 
 =head1 VERSION
 
-version 1.200009
+version 1.200010
 
 =for test_synopsis BEGIN { die "SKIP: synopsis isn't perl code" }
 
